# Data Science Utils

This is a Python pacakage that contains misc utils for Data Science.

1. Misc enhancement of Python's built-in functionalities.
    - string
    - collections
    - pandas DataFrame
    - datetime
2. Misc other tools
    - git
      ```
      aiutil.git.check
      ```
    - text manipulation
    - html
    - misc
    
## Requirements
`aiutil` requires Python 3.6+. 

## Installation

You can download a copy of the latest release and install it using pip.
```
pip3 install --user -U https://github.com/dclong/aiutil/releases/download/v1.0.0/aiutil-1.0.0-py3-none-any.whl
```
Or you can use the following command to install the latest master branch
if you have pip 20.0+.
```
pip3 install --user -U git+https://github.com/dclong/aiutil@master
```
